==> llm-docs-0.1.2.tgz: package/docs/integration/shared-utilities.md <==
---
id: integration-shared-utilities
---
# Shared Utilities Integration

This document provides guidance on integrating the shared utilities from `@bluefly/bfcli/shared` into your project.

## Overview

The Bluefly shared utilities provide standardized implementations of common functionality across all Bluefly projects. These utilities cover error handling, logging, HTTP client functionality, observability, and general utilities.

## Integration Steps

Follow these steps to integrate the shared utilities into your project:

1. **Add the dependency**:

```bash
npm install @bluefly/bfcli
```

2. **Update package.json**:

```json
{
  "dependencies": {
    "@bluefly/bfcli": "^1.0.0"
  }
}
```

3. **Import the utilities**:

```typescript
// Import with .js extension for ESM compatibility
import { logger } from '@bluefly/bfcli/shared/logger/index.js';
import { createError } from '@bluefly/bfcli/shared/errors/index.js';
import { HttpClient } from '@bluefly/bfcli/shared/http/index.js';
```

4. **Create service-specific instances**:

```typescript
// Create a service-specific logger
const serviceLogger = new BlueflyLogger({
  prefix: '[my-service]',
  level: process.env.LOG_LEVEL || 'info'
});

// Create a service-specific HTTP client
const httpClient = new HttpClient({
  baseURL: process.env.API_URL,
  timeout: 5000,
  retries: 3
});
```

## Migrating Existing Code

### Logger Migration

Replace your custom logger implementation with the shared logger:

**Before**:
```typescript
// Old custom logger
export function log(level, message, context) {
  console.log(`[${level}] ${message}`, context);
}
```

**After**:
```typescript
import { BlueflyLogger } from '@bluefly/bfcli/shared';

// Create a service-specific logger
export const logger = new BlueflyLogger({
  prefix: '[my-service]',
  level: process.env.LOG_LEVEL || 'info'
});

// For backward compatibility
export function log(level, message, context) {
  switch (level) {
    case 'debug': logger.debug(message, context); break;
    case 'info': logger.info(message, context); break;
    case 'warn': logger.warn(message, context); break;
    case 'error': logger.error(message, context); break;
    default: logger.info(message, context);
  }
}
```

### Error Handling Migration

Replace custom error classes with shared error utilities:

**Before**:
```typescript
// Old custom error
export class ApiError extends Error {
  constructor(message, status) {
    super(message);
    this.status = status;
  }
}
```

**After**:
```typescript
import { createError, ERROR_CODES } from '@bluefly/bfcli/shared';

// Using shared error utilities
export function createApiError(message, status) {
  return createError(
    message,
    ERROR_CODES.API_ERROR,
    status,
    { service: 'my-service' }
  );
}
```

### HTTP Client Migration

Replace custom HTTP client with shared HTTP client:

**Before**:
```typescript
// Old custom HTTP client
import axios from 'axios';

export async function apiRequest(url, method, data) {
  try {
    const response = await axios({ url, method, data });
    return response.data;
  } catch (error) {
    handleError(error);
  }
}
```

**After**:
```typescript
import { HttpClient } from '@bluefly/bfcli/shared';

// Create service-specific client
const httpClient = new HttpClient({
  baseURL: process.env.API_URL,
  timeout: 5000,
  retries: 3
});

export async function apiRequest(url, method, data) {
  try {
    const response = await httpClient.request({
      url,
      method,
      data
    });
    return response.data;
  } catch (error) {
    // Error is already standardized
    throw error;
  }
}
```

## Configuration

The shared utilities can be configured through environment variables:

```
# Logger configuration
LOG_LEVEL=debug
LOG_FORMAT=json
LOG_COLORIZE=true

# HTTP client configuration
HTTP_TIMEOUT=10000
HTTP_RETRIES=3
HTTP_RETRY_DELAY=1000
```

## Best Practices

1. **Use ES Module Imports**: Always use `.js` extension in import paths
   ```typescript
   import { createError } from '@bluefly/bfcli/shared/errors/index.js';
   ```

2. **Service-Specific Configuration**: Create service-specific instances
   ```typescript
   const logger = new BlueflyLogger({ prefix: '[my-service]' });
   ```

3. **Contextual Logging**: Include relevant context in logs
   ```typescript
   logger.info('User action', { userId, action, correlationId });
   ```

4. **Error Handling**: Use the shared error system consistently
   ```typescript
   try {
     // Operation
   } catch (error) {
     throw translateError(error);
   }
   ```

5. **HTTP Requests**: Use the shared HTTP client for all requests
   ```typescript
   const response = await httpClient.get('/users/123');
   ```

## Migration Scripts

Use the migration scripts to automate the migration process:

```bash
node ./bfcli/shared/scripts/migrate-[project].js
```

Available migration scripts:

- `migrate-bfapi.js` - BFAPI migration
- `migrate-bfllm.js` - BFLLM migration
- `migrate-bfmcp.js` - BFMCP migration
- `migrate-bfrfp.js` - BFRFP migration
- `migrate-bfapiclient.js` - BFAPICLIENT migration
- `migrate-bfui.js` - BFUI migration
- `migrate-bfcicomponents.js` - BFCICOMPONENTS migration
- `migrate-bfdocs.js` - BFDOCS migration

## Further Reading

- [Shared Components Reference](../../shared/SHARED_COMPONENTS)
- [Migration Guide](../../shared/SHARED_UTILITIES_MIGRATION_GUIDE)
- [Migration Progress](../../shared/MIGRATION_PROGRESS)
- [Migration Summary](../../shared/MIGRATION_SUMMARY)

## Support

For issues with shared utilities, contact the Bluefly Platform Team or open an issue in the BFCLI repository.

==> llm-docs-0.1.4.tgz: package/docs/integration/shared-utilities.md <==
---
id: integration-shared-utilities
---
# Shared Utilities Integration

This document provides guidance on integrating the shared utilities from `@bluefly/llmcli/shared` into your project.

## Overview

The LLM Platform shared utilities provide standardized implementations of common functionality across all LLM Platform projects. These utilities cover error handling, logging, HTTP client functionality, observability, and general utilities.

## Integration Steps

Follow these steps to integrate the shared utilities into your project:

1. **Add the dependency**:

```bash
npm install @bluefly/llmcli
```

2. **Update package.json**:

```json
{
  "dependencies": {
    "@bluefly/llmcli": "^1.0.0"
  }
}
```

3. **Import the utilities**:

```typescript
// Import with .js extension for ESM compatibility
import { logger } from '@bluefly/llmcli/shared/logger/index.js';
import { createError } from '@bluefly/llmcli/shared/errors/index.js';
import { HttpClient } from '@bluefly/llmcli/shared/http/index.js';
```

4. **Create service-specific instances**:

```typescript
// Create a service-specific logger
const serviceLogger = new LLM PlatformLogger({
  prefix: '[my-service]',
  level: process.env.LOG_LEVEL || 'info'
});

// Create a service-specific HTTP client
const httpClient = new HttpClient({
  baseURL: process.env.API_URL,
  timeout: 5000,
  retries: 3
});
```

## Migrating Existing Code

### Logger Migration

Replace your custom logger implementation with the shared logger:

**Before**:
```typescript
// Old custom logger
export function log(level, message, context) {
  console.log(`[${level}] ${message}`, context);
}
```

**After**:
```typescript
import { LLM PlatformLogger } from '@bluefly/llmcli/shared';

// Create a service-specific logger
export const logger = new LLM PlatformLogger({
  prefix: '[my-service]',
  level: process.env.LOG_LEVEL || 'info'
});

// For backward compatibility
export function log(level, message, context) {
  switch (level) {
    case 'debug': logger.debug(message, context); break;
    case 'info': logger.info(message, context); break;
    case 'warn': logger.warn(message, context); break;
    case 'error': logger.error(message, context); break;
    default: logger.info(message, context);
  }
}
```

### Error Handling Migration

Replace custom error classes with shared error utilities:

**Before**:
```typescript
// Old custom error
export class ApiError extends Error {
  constructor(message, status) {
    super(message);
    this.status = status;
  }
}
```

**After**:
```typescript
import { createError, ERROR_CODES } from '@bluefly/llmcli/shared';

// Using shared error utilities
export function createApiError(message, status) {
  return createError(
    message,
    ERROR_CODES.API_ERROR,
    status,
    { service: 'my-service' }
  );
}
```

### HTTP Client Migration

Replace custom HTTP client with shared HTTP client:

**Before**:
```typescript
// Old custom HTTP client
import axios from 'axios';

export async function apiRequest(url, method, data) {
  try {
    const response = await axios({ url, method, data });
    return response.data;
  } catch (error) {
    handleError(error);
  }
}
```

**After**:
```typescript
import { HttpClient } from '@bluefly/llmcli/shared';

// Create service-specific client
const httpClient = new HttpClient({
  baseURL: process.env.API_URL,
  timeout: 5000,
  retries: 3
});

export async function apiRequest(url, method, data) {
  try {
    const response = await httpClient.request({
      url,
      method,
      data
    });
    return response.data;
  } catch (error) {
    // Error is already standardized
    throw error;
  }
}
```

## Configuration

The shared utilities can be configured through environment variables:

```
# Logger configuration
LOG_LEVEL=debug
LOG_FORMAT=json
LOG_COLORIZE=true

# HTTP client configuration
HTTP_TIMEOUT=10000
HTTP_RETRIES=3
HTTP_RETRY_DELAY=1000
```

## Best Practices

1. **Use ES Module Imports**: Always use `.js` extension in import paths
   ```typescript
   import { createError } from '@bluefly/llmcli/shared/errors/index.js';
   ```

2. **Service-Specific Configuration**: Create service-specific instances
   ```typescript
   const logger = new LLM PlatformLogger({ prefix: '[my-service]' });
   ```

3. **Contextual Logging**: Include relevant context in logs
   ```typescript
   logger.info('User action', { userId, action, correlationId });
   ```

4. **Error Handling**: Use the shared error system consistently
   ```typescript
   try {
     // Operation
   } catch (error) {
     throw translateError(error);
   }
   ```

5. **HTTP Requests**: Use the shared HTTP client for all requests
   ```typescript
   const response = await httpClient.get('/users/123');
   ```

## Migration Scripts

Use the migration scripts to automate the migration process:

```bash
node ./llmcli/shared/scripts/migrate-[project].js
```

Available migration scripts:

- `migrate-bfapi.js` - BFAPI migration
- `migrate-bfllm.js` - BFLLM migration
- `migrate-llm-mcp.js` - llm-mcp migration
- `migrate-bfrfp.js` - BFRFP migration
- `migrate-llm-gateway-sdk.js` - llm-gateway-sdk migration
- `migrate-llm-ui.js` - llm-ui migration
- `migrate-bfcicomponents.js` - BFCICOMPONENTS migration
- `migrate-bfdocs.js` - BFDOCS migration

## Further Reading

- [Shared Components Reference](../../shared/SHARED_COMPONENTS)
- [Migration Guide](../../shared/SHARED_UTILITIES_MIGRATION_GUIDE)
- [Migration Progress](../../shared/MIGRATION_PROGRESS)
- [Migration Summary](../../shared/MIGRATION_SUMMARY)

## Support

For issues with shared utilities, contact the LLM Platform Platform Team or open an issue in the llmcli repository.
